pub enum AccessLeaseStatus {
Active,
Expired,
Revoked,
__Unknown(i64),
}Expand description
AccessLeaseStatus : The lifecycle state of an access lease, as it appears on the wire: 0 = active, 1 = expired, 2 = revoked. The lifecycle state of an access lease, as it appears on
the wire: 0 = active, 1 = expired, 2 = revoked.
Variants
Active
Expired
Revoked
__Unknown(i64)
Unknown value returned from the server. This is used to handle forward compatibility.
Implementations